/***********************************************************************************************************************
 *
 * forceTen - open source geography
 * ================================
 *
 * Copyright (C) 2007-2010 by Tidalwave s.a.s.
 * Project home page: http://forceten.tidalwave.it
 *
 ***********************************************************************************************************************
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations under the License.
 *
 ***********************************************************************************************************************
 *
 * $Id: GeoLocationNodeFactoryImpl.java,v 432868f2116d 2009/12/31 23:28:20 fabrizio $
 *
 **********************************************************************************************************************/
package it.tidalwave.geo.location.node.impl;

import javax.annotation.CheckForNull;
import javax.annotation.Nonnull;
import javax.annotation.concurrent.ThreadSafe;
import java.awt.Image;
import org.openide.nodes.Node;
import org.openide.util.ImageUtilities;
import it.tidalwave.swing.IconResizer;
import it.tidalwave.netbeans.nodes.NodeFactorySupport;
import it.tidalwave.netbeans.nodes.role.RootNodeProvider;
import it.tidalwave.geo.location.GeoLocation;
import it.tidalwave.geo.location.GeoSchema;

/***********************************************************************************************************************
 *
 * @author  Fabrizio Giudici
 * @version $Id: GeoLocationNodeFactoryImpl.java,v 432868f2116d 2009/12/31 23:28:20 fabrizio $
 *
 **********************************************************************************************************************/
@ThreadSafe
public class GeoLocationNodeFactoryImpl extends NodeFactorySupport implements RootNodeProvider
  {
    @CheckForNull
    private Node rootNode;

    @Nonnull
    private final GeoSchema geoSchema;

    @CheckForNull
    private Image defaultIcon;
            
    /*******************************************************************************************************************
     *
     *
     ******************************************************************************************************************/
    public GeoLocationNodeFactoryImpl (final @Nonnull GeoSchema geoSchema)
      {
        this.geoSchema = geoSchema;
        configureActions(GeoLocationNode.class, "it.tidalwave.geo.location.node.GeoLocationNode");
        
//        registerIcon(AllTripsNode.class, "luggage.png");
      }

    /*******************************************************************************************************************
     *
     * {@inheritDoc}
     *
     ******************************************************************************************************************/
    @Override
    @Nonnull
    public synchronized Node getRootNode()
      {
        if (rootNode == null)
          {
            final GeoLocation root = geoSchema.getRoot();
            rootNode = new GeoLocationNode(geoSchema, root, this);
          }
        
        return rootNode;
      }
    
    /*******************************************************************************************************************
     *
     * {@inheritDoc}
     *
     ******************************************************************************************************************/
    @Override
    @Nonnull
    public synchronized Image findIcon (final @Nonnull Node node)
      {
        if (defaultIcon == null)
          {
            defaultIcon = ImageUtilities.loadImage("it/tidalwave/geo/location/node/impl/icons/default.png");
            assert defaultIcon != null : "null default icon";
            defaultIcon = IconResizer.scaledImage(defaultIcon, 16);
          }

        return defaultIcon;
      }
  }
